@@ -1,6 +1,6 @@
 package DBIx::Class::Async::Row;
 
-$DBIx::Class::Async::Row::VERSION   = '0.52';
+$DBIx::Class::Async::Row::VERSION   = '0.53';
 $DBIx::Class::Async::Row::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ DBIx::Class::Async::Row - Asynchronous Row object representing a single database
 
 =head1 VERSION
 
-Version 0.52
+Version 0.53
 
 =head1 SYNOPSIS
 
@@ -326,14 +326,14 @@ sub discard_changes {
             return Future->fail("Row vanished from database", 'db_error');
         }
 
-        # 3. Synchronize internal state
+        # 3. Synchronise internal state
         # We extract the columns from the fresh object into this one
         my $raw_data = $fresh_row->{_data};
 
         $self->{_data}  = { %$raw_data };
         $self->{_dirty} = {};
 
-        # 4. Refresh speed shadows (Warm-up optimization)
+        # 4. Refresh speed shadows (Warm-up optimisation)
         $self->_ensure_accessors;
 
         return Future->done($self);
@@ -555,7 +555,7 @@ sub related_resultset {
         }
     }
 
-    # 3. Finalize condition and source name
+    # 3. Finalise condition and source name
     my $final_cond = { %$join_cond, %{ $cond || {} } };
     my $foreign_source_name = $rel_info->{source};
 
@@ -949,7 +949,7 @@ sub AUTOLOAD {
 
     # THE HIJACK GUARD
     # ----------------------------------------------------------------------
-    # If we reached here, Async::Row doesn't recognize this as a DB column.
+    # If we reached here, Async::Row doesn't recognise this as a DB column.
     # We check if a custom class further up the @ISA chain has this method.
 
     # 'can' looks through the entire inheritance tree (MRO)
@@ -1326,7 +1326,9 @@ Returns information about the primary key(s) for this row.
 Hash reference with keys:
 
 - C<columns>: Array reference of primary key column names
+
 - C<count>: Number of primary key columns
+
 - C<is_composite>: Boolean indicating composite primary key
 
 =back
@@ -1426,6 +1428,76 @@ as fast as subsequent ones.
 
 =back
 
+=head1 AUTHOR
+
+Mohammad Sajid Anwar, C<< <mohammad.anwar at yahoo.com> >>
+
+=head1 REPOSITORY
+
+L<https://github.com/manwar/DBIx-Class-Async>
+
+=head1 BUGS
+
+Please report any bugs or feature requests through the web interface at L<https://github.com/manwar/DBIx-Class-Async/issues>.
+I will  be notified and then you'll automatically be notified of progress on your
+bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc DBIx::Class::Async::Row
+
+You can also look for information at:
+
+=over 4
+
+=item * BUG Report
+
+L<https://github.com/manwar/DBIx-Class-Async/issues>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/DBIx-Class-Async>
+
+=item * Search MetaCPAN
+
+L<https://metacpan.org/dist/DBIx-Class-Async/>
+
+=back
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (C) 2026 Mohammad Sajid Anwar.
+
+This program  is  free software; you can redistribute it and / or modify it under
+the  terms  of the the Artistic License (2.0). You may obtain a  copy of the full
+license at:
+L<http://www.perlfoundation.org/artistic_license_2_0>
+Any  use,  modification, and distribution of the Standard or Modified Versions is
+governed by this Artistic License.By using, modifying or distributing the Package,
+you accept this license. Do not use, modify, or distribute the Package, if you do
+not accept this license.
+If your Modified Version has been derived from a Modified Version made by someone
+other than you,you are nevertheless required to ensure that your Modified Version
+ complies with the requirements of this license.
+This  license  does  not grant you the right to use any trademark,  service mark,
+tradename, or logo of the Copyright Holder.
+This license includes the non-exclusive, worldwide, free-of-charge patent license
+to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
+Package with respect to any patent claims licensable by the Copyright Holder that
+are  necessarily  infringed  by  the  Package. If you institute patent litigation
+(including  a  cross-claim  or  counterclaim) against any party alleging that the
+Package constitutes direct or contributory patent infringement,then this Artistic
+License to you shall terminate on the date that such litigation is filed.
+Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
+CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
+WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
+NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
+REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
+INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
+OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 =cut
 
 1; # End of DBIx::Class::Async::Row
